@@ -152,7 +152,10 @@ savePMML <- function(doc, name, version=4.3)
    adapaPrefix0 <- "<?xml version=\"1.0\" encoding=\"UTF-8\"?>\n<!--(Comment generated by ADAPA)" 
    adapaPrefix1 <- paste("PMML processed by ADAPA (Version : ",sprintf("%.1f",version),")-->\n",sep="")
    adapaPrefix <- paste(adapaPrefix0,adapaPrefix1)
-   saveXML(doc,name,prefix=adapaPrefix)  
+   
+   output_file <- file(name,"wb")
+   saveXML(doc,output_file,prefix=adapaPrefix)
+   close(output_file)
 }
 
 
